/*
 * Bibliothek - DockingFrames
 * Library built on Java/Swing, allows the user to "drag and drop"
 * panels containing any Swing-Component the developer likes to add.
 * 
 * Copyright (C) 2009 Benjamin Sigg
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 * Benjamin Sigg
 * benjamin_sigg@gmx.ch
 * CH - Switzerland
 */
package bibliothek.gui.dock.facile.mode.action;

import java.util.ResourceBundle;

import bibliothek.gui.DockController;
import bibliothek.gui.Dockable;
import bibliothek.gui.dock.common.CControl;
import bibliothek.gui.dock.facile.mode.ExternalizedMode;
import bibliothek.gui.dock.support.mode.Mode;
import bibliothek.gui.dock.support.util.Resources;

/**
 * An action used to change the {@link Mode} of a {@link Dockable} to
 * the {@link ExternalizedMode}.
 * @author Benjamin Sigg
 */
public class ExternalizedModeAction extends LocationModeAction{
	/**
	 * Creates a new action.
	 * @param controller the controller in whose realm this action is used
	 * @param mode the mode which is applied
	 */
	public ExternalizedModeAction( DockController controller, ExternalizedMode<?> mode ){
		super( controller, mode, "externalize", ExternalizedMode.ICON_IDENTIFIER, CControl.KEY_GOTO_EXTERNALIZED );
		
        ResourceBundle bundle = Resources.getBundle();
        
        setText( bundle.getString( "externalize.in" ) );
        setTooltip( bundle.getString( "externalize.in.tooltip" ) );
	}
}
